//allows for printing with features, but uses more memory
#define RPRINTF_FLOAT
#define RPRINTF_COMPLEX

#include "hardware.h"

#include "VR_library.h"		//voice recognition library


// Initialise the hardware
void appInitHardware(void) {
	initHardware();


}
// Initialise the software
TICK_COUNT appInitSoftware(TICK_COUNT loopStart){

	servosDisconnect(&bank1);

	delay_ms(1200);//Axon II bootup time

	rprintf("\n\nAxon Initiated\n");

	VR_Module_init();

	return 0;
}
// This is the main loop
TICK_COUNT appControl(LOOP_COUNT loopCount, TICK_COUNT loopStart) {

	int8_t voice_command=-2;

	//start voice recognition (note: it times out)
	VR_Module_start_recognition(VR_group);//group B
	
	while(voice_command == -2)
		voice_command = VR_Module_get_result();

	if(voice_command >= 0)
		{
		rprintf("\nvoice command is: ");

		//turn on servos (I turn off to prevent noise interference)
		act_setConnected(&wheel_left, TRUE);
		act_setConnected(&wheel_right, TRUE);

		//swap languages - not used in this example, as both languages are set to do the same
		if(VR_group==1 && voice_command==0)
			{
			rprintf(" THAI");
			VR_group=2;
			}
		else if(VR_group==2 && voice_command==0)
			{
			rprintf(" ENGLISH");
			VR_group=1;
			}
		
		//other commands
		else if(voice_command==1)
			{
			act_setSpeed(&wheel_left,127);
			act_setSpeed(&wheel_right,-127);
			rprintf(" LEFT");
			delay_ms(500);
			}
		else if(voice_command==2)
			{
			act_setSpeed(&wheel_left,-127);
			act_setSpeed(&wheel_right,127);
			rprintf(" RIGHT");
			delay_ms(500);
			}
		else if(voice_command==3)
			{
			act_setSpeed(&wheel_left,127);
			act_setSpeed(&wheel_right,127);
			rprintf(" FORWARD");
			delay_ms(1500);
			}
		else if(voice_command==4)
			{
			rprintf(" DANCE");
			//forward
			act_setSpeed(&wheel_left,127);
			act_setSpeed(&wheel_right,127);
			delay_ms(600);
			//reverse
			act_setSpeed(&wheel_left,127);
			act_setSpeed(&wheel_right,127);
			delay_ms(600);
			//spin right
			act_setSpeed(&wheel_left,-127);
			act_setSpeed(&wheel_right,127);
			delay_ms(1200);
			//spin left
			act_setSpeed(&wheel_left,127);
			act_setSpeed(&wheel_right,-127);
			delay_ms(1200);
			}
		else if(voice_command==5)
			rprintf(" WAI PRA");
		else if(voice_command==6)
			rprintf(" WORSHIP");
		else if(voice_command==7)
			rprintf(" ARM");
		else if(voice_command==8)
			rprintf(" ATTACK");
		else if(voice_command==9)
			{
			rprintf(" SHUTDOWN");
			servosDisconnect(&bank1);
			}
		else if(voice_command==10)
			{
			rprintf(" POWER_UP");
			servosConnect(&bank1);
			}
		else if(voice_command==11)
			{
			LED_off(&statusLED);
			rprintf(" LED");
			delay_ms(2000);
			LED_on(&statusLED);
			}
		else if(voice_command==12)
			{
			act_setSpeed(&elbow,80);
			rprintf(" UP");
			}
		else if(voice_command==13)
			{
			act_setSpeed(&elbow,-80);
			rprintf(" DOWN");
			}
		else if(voice_command==14)
			{
			act_setSpeed(&gripper,-50);
			rprintf(" GRAB");
			}
		else if(voice_command==15)
			{
			act_setSpeed(&gripper,50);
			rprintf(" RELEASE");
			}

		//stop further motion and turn off servos
		act_setSpeed(&wheel_left,0);
		act_setSpeed(&wheel_right,0);
		act_setConnected(&wheel_left, FALSE);
		act_setConnected(&wheel_right, FALSE);
		}
	
	rprintf("\n");
	delay_ms(100);

	return 0;
}

/*
Group 1: 
0 PASA_THAI
1 LEFT
2 RIGHT
3 FORWARD
4 DANCE
5 WAI PRA
6 WORSHIP
7 ARM
8 ATTACK
9 SHUTDOWN
10 POWER_UP
11 LED
12 UP
13 DOWN
14 GRAB
15 RELEASE

Group 2:
0 PASA_ANGRIT
1 LEO_SAI
2 LEO_KWA
3 DTRONG_BAI
4 DTEN LOY
5 WAI PRA
6 KOWROP BUUCHAA
7 KAEN
8 HAA REUNG
9 BID FAI
10 BERD FAI
11 LED
12 KEUN
13 LONG
14 JAB MAN
15 BLOY MAN
*/
